From 0bc228446c1f680f14aff72dbfd85dc5edd0043e Mon Sep 17 00:00:00 2001
From: mcramer <m.cramer@pixcept.de>
Date: Fri, 12 Jul 2013 09:59:37 -0400
Subject: [PATCH] - Changed installer template handling   It is now possible to put a customized copy of each .master template file into   /usr/local/ispconfig/server/conf-custom/install/   to keep manual changes done in this file.   If existing, these .master files are used on ISPConfig upgrade instead of the provided installer templates.

---
 interface/web/admin/users_list.php |    8 +++-----
 1 files changed, 3 insertions(+), 5 deletions(-)

diff --git a/interface/web/admin/users_list.php b/interface/web/admin/users_list.php
index 105922d..412d4fa 100644
--- a/interface/web/admin/users_list.php
+++ b/interface/web/admin/users_list.php
@@ -41,13 +41,11 @@
 * End Form configuration
 ******************************************/
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],$_SESSION["s"]["module"]["name"])) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('admin');
 
 $app->uses('listform_actions');
+$app->listform_actions->SQLOrderBy = 'ORDER BY sys_user.username';
 $app->listform_actions->onLoad();
 
 

--
Gitblit v1.9.1